@@ -223,9 +223,8 @@ public:
      * @param state The icon state: @p DefaultState, @p ActiveState or
      * @p DisabledState. Depending on the user's preferences, the iconloader
      * may apply a visual effect to hint about its state.
-     * @param overlays a list of emblem icons to overlay, by name. the emblem
-     *                 prefix is applied automatically to each name, e.g.
-     *                 "zip" becomes "emblem-zip"
+     * @param overlays a list of emblem icons to overlay, by name
+     *                 @see drawOverlays
      * @param path_store If not null, the path of the icon is stored here,
      *        if the icon was found. If the icon was not found @p path_store
      *        is unaltered even if the "unknown" pixmap was returned.
@@ -255,9 +254,8 @@ public:
      * @p DisabledState. Depending on the user's preferences, the iconloader
      * may apply a visual effect to hint about its state.
      * @param path_store If not null, the path of the icon is stored here.
-     * @param overlays a list of emblem icons to overlay, by name. the emblem
-     *                 prefix is applied automatically to each name, e.g.
-     *                 "zip" becomes "emblem-zip"
+     * @param overlays a list of emblem icons to overlay, by name
+     *                 @see drawOverlays
      * @return the QPixmap. Can not be null, the
      * "unknown" pixmap is returned when no appropriate icon has been found.
      */
@@ -291,7 +289,7 @@ public:
      *
      * @deprecated use QIcon::fromTheme instead, which uses the iconloader internally
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KICONTHEMES_NO_DEPRECATED
     KICONTHEMES_DEPRECATED QIcon loadIconSet(const QString &name, KIconLoader::Group group, int size = 0,
             bool canReturnNull = false);
 #endif
@@ -422,11 +420,12 @@ public:
     KIconEffect *iconEffect() const;
 
     /**
-     * Called by newIconLoader to reconfigure the icon loader.
-     * @param _appname the new application name
+     * Reconfigure the icon loader, for instance to change the associated app name or extra search paths.
+     * This also clears the in-memory pixmap cache (even if the appname didn't change, which is useful for unittests)
+     * @param appname the application name (empty for the global iconloader)
      * @param extraSearchPaths additional search paths, either absolute or relative to GenericDataLocation
      */
-    void reconfigure(const QString &_appname, const QStringList &extraSearchPaths = QStringList());
+    void reconfigure(const QString &appname, const QStringList &extraSearchPaths = QStringList());
 
     /**
      * Returns the unknown icon. An icon that is used when no other icon
@@ -447,19 +446,23 @@ public:
     /**
      * Draws overlays on the specified pixmap, it takes the width and height
      * of the pixmap into consideration
-     * @param overlays to draw
+     * @param overlays List of up to 4 overlays to blend over the pixmap. The first overlay
+     *                 will be in the bottom left corner, followed by bottom right, top right
+     *                 and top left. An empty QString can be used to leave the specific position
+     *                 blank.
      * @param pixmap to draw on
      * @since 4.7
      */
     void drawOverlays(const QStringList &overlays, QPixmap &pixmap, KIconLoader::Group group, int state = KIconLoader::DefaultState) const;
 
+    bool hasIcon(const QString &iconName) const;
 public Q_SLOTS:
     /**
      * Re-initialize the global icon loader
      *
      * @deprecated since 5.0, use emitChange(Group)
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KICONTHEMES_NO_DEPRECATED
     KICONTHEMES_DEPRECATED void newIconLoader();
 #endif
 
@@ -506,7 +509,7 @@ KICONTHEMES_EXPORT QPixmap DesktopIcon(const QString &name, int size = 0,
  * Load a desktop icon, and apply the necessary effects to get an IconSet.
  * @deprecated use QIcon::fromTheme instead
  */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KICONTHEMES_NO_DEPRECATED
 KICONTHEMES_DEPRECATED_EXPORT QIcon DesktopIconSet(const QString &name, int size = 0);
 #endif
 
@@ -522,7 +525,7 @@ KICONTHEMES_EXPORT QPixmap BarIcon(const QString &name, int size = 0, int state
  * Load a toolbar icon, and apply the necessary effects to get an IconSet.
  * @deprecated use QIcon::fromTheme instead
  */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KICONTHEMES_NO_DEPRECATED
 KICONTHEMES_DEPRECATED_EXPORT QIcon BarIconSet(const QString &name, int size = 0);
 #endif
 
@@ -538,7 +541,7 @@ KICONTHEMES_EXPORT QPixmap SmallIcon(const QString &name, int size = 0,
  * Load a small icon, and apply the necessary effects to get an IconSet.
  * @deprecated use QIcon::fromTheme instead
  */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KICONTHEMES_NO_DEPRECATED
 KICONTHEMES_DEPRECATED_EXPORT QIcon SmallIconSet(const QString &name, int size = 0);
 #endif
 
@@ -554,7 +557,7 @@ KICONTHEMES_EXPORT QPixmap MainBarIcon(const QString &name, int size = 0,
  * Load a main toolbar icon, and apply the effects to get an IconSet.
  * @deprecated use QIcon::fromTheme instead
  */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KICONTHEMES_NO_DEPRECATED
 KICONTHEMES_DEPRECATED_EXPORT QIcon MainBarIconSet(const QString &name, int size = 0);
 #endif
 
@@ -569,7 +572,7 @@ KICONTHEMES_EXPORT QPixmap UserIcon(const QString &name, int state = KIconLoader
  * Load a user icon, and apply the effects to get an IconSet.
  * @deprecated use QIcon::fromTheme instead
  */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KICONTHEMES_NO_DEPRECATED
 KICONTHEMES_DEPRECATED_EXPORT QIcon UserIconSet(const QString &name);
 #endif
 
